#ifndef _FS_ACTIONCALLBACK_C_H_
#define _FS_ACTIONCALLBACK_C_H_

#ifdef __cplusplus
extern "C" {
#endif


struct FSMenuList {
  int level;
  FS_WSTR name;
  FSMenuList* sub_menu_list_array;
  FS_UINT32 sub_menu_list_array_length;
};

struct FSMenuItemEx {
  FS_WSTR item_name;
  FS_BOOL is_checked;
  FS_BOOL is_enabled;
  FS_WSTR return_name;
  FSMenuItemEx* sub_menu_item_array;
  FS_UINT32 sub_menu_item_array_length;
};

struct FSIdentityProperties {
  FS_WSTR corporation;
  FS_WSTR email;
  FS_WSTR login_name;
  FS_WSTR name;
  FS_WSTR first_name;
  FS_WSTR last_name;
  FS_WSTR title;
  FS_WSTR department;
};


typedef enum _FSLanguage {
e_FSLanguageLanguageUnknown = 0,
e_FSLanguageCHS = 1,
e_FSLanguageCHT = 2,
e_FSLanguageDAN = 3,
e_FSLanguageDEU = 4,
e_FSLanguageENU = 5,
e_FSLanguageESP = 6,
e_FSLanguageFRA = 7,
e_FSLanguageITA = 8,
e_FSLanguageKOR = 9,
e_FSLanguageJPN = 10,
e_FSLanguageNLD = 11,
e_FSLanguageNOR = 12,
e_FSLanguagePTB = 13,
e_FSLanguageSUO = 14,
e_FSLanguageSVE = 15,
}FSLanguage;



typedef enum _FSAppInfoType {
e_FSAppInfoTypeFormsVersion = 0x0,
e_FSAppInfoTypeViewerType = 0x01,
e_FSAppInfoTypeViewerVariation = 0x02,
e_FSAppInfoTypeViewerVersion = 0x03,
e_FSAppInfoTypeAppVersion = 0x04,
}FSAppInfoType;



typedef enum _FSMailType {
e_FSMailTypeDoc = 0,
e_FSMailTypeForm = 1,
e_FSMailTypeMsg = 2,
}FSMailType;


struct FSActionCallback {
  void* user_data;
  void (*Release)(void* user_data);
  FS_BOOL (*InvalidateRect)(void* user_data, const FS_PDFDOC_HANDLE& document, int page_index, const FSRectF& pdf_rect);
  int (*GetCurrentPage)(void* user_data, const FS_PDFDOC_HANDLE& document);
  void (*SetCurrentPage)(void* user_data, const FS_PDFDOC_HANDLE& document, int page_index);
  FSRotation (*GetPageRotation)(void* user_data, const FS_PDFDOC_HANDLE& document, int page_index);
  FS_BOOL (*SetPageRotation)(void* user_data, const FS_PDFDOC_HANDLE& document, int page_index, FSRotation rotation);
  FS_BOOL (*ExecuteNamedAction)(void* user_data, const FS_PDFDOC_HANDLE& document, const char* named_action);
  FS_BOOL (*SetDocChangeMark)(void* user_data, const FS_PDFDOC_HANDLE& document, FS_BOOL change_mark);
  FS_BOOL (*GetDocChangeMark)(void* user_data, const FS_PDFDOC_HANDLE& document);
  int (*GetOpenedDocCount)(void* user_data);
  FS_PDFDOC_HANDLE (*GetOpenedDoc)(void* user_data, int index);
  FS_PDFDOC_HANDLE (*GetCurrentDoc)(void* user_data);
  FS_PDFDOC_HANDLE (*CreateBlankDoc)(void* user_data);
  FS_BOOL (*OpenDoc)(void* user_data, const wchar_t* file_path, const FS_WSTR* password);
  FS_BOOL (*Beep)(void* user_data, int type);
  FS_WSTR (*FSResponse)(void* user_data, const wchar_t* question, const wchar_t* title, const wchar_t* default_value,
                                const wchar_t* label, FS_BOOL is_password);
  FS_WSTR (*GetFilePath)(void* user_data, const FS_PDFDOC_HANDLE& document);
  FS_BOOL (*Print)(void* user_data, const FS_PDFDOC_HANDLE& document, FS_BOOL is_ui,
                     const FS_RANGE_HANDLE& page_range, FS_BOOL is_silent ,
                     FS_BOOL is_shrunk_to_fit, FS_BOOL is_printed_as_image,
                     FS_BOOL is_reversed, FS_BOOL is_to_print_annots);
  FS_BOOL (*SubmitForm)(void* user_data, const FS_PDFDOC_HANDLE& document, void* form_data, FS_UINT32 length, const char* url, FSFileFormatType file_format_type);
  FS_BOOL (*LaunchURL)(void* user_data, const char* url);
  FS_WSTR (*BrowseFile)(void* user_data);
  FS_WSTR (*BrowseFile0)(void* user_data, FS_BOOL is_open_dialog, const wchar_t* file_format, const wchar_t* file_filter);
  FSLanguage (*GetLanguage)(void* user_data);
  int (*Alert)(void* user_data, const wchar_t* msg, const wchar_t* title, int type, int icon);
  FSIdentityProperties (*GetIdentityProperties)(void* user_data);
  FS_BOOL (*SetIdentityProperties)(void* user_data, const FSIdentityProperties& identity_properties);
  FS_WSTR (*PopupMenu)(void* user_data, FSMenuList* menulist_array, FS_UINT32 array_length_menus, FS_BOOL& is_selected_item);
  FSMenuItemEx (*PopupMenuEx)(void* user_data, FSMenuItemEx* menuitem_array, FS_UINT32 array_length_menus, FS_BOOL& is_selected_item);
  FS_WSTR (*GetAppInfo)(void* user_data, FSAppInfoType type);
  FS_BOOL (*MailData)(void* user_data, void* data, FSMailType data_type, FS_BOOL is_ui, const wchar_t* to,
                        const wchar_t* subject, const wchar_t* cc, const wchar_t* bcc, const wchar_t* message);
  FS_UINT32 (*VerifySignature)(void* user_data, const FS_PDFDOC_HANDLE& document, const FS_SIGNATURE_HANDLE& pdf_signature);
};

#ifdef __cplusplus
}
#endif
#endif
